@@ -55,12 +55,15 @@ resource "azurerm_storage_account_network_rules" "good_example" {
 		RequiredTypes:   []string{"resource"},
 		RequiredLabels:  []string{"azurerm_storage_account", "azurerm_storage_account_network_rules"},
 		DefaultSeverity: severity.Critical,
-		CheckFunc: func(set result.Set, resourceBlock block.Block, _ block.Module) {
+		CheckFunc: func(set result.Set, resourceBlock block.Block, ctx block.Module) {
 
 			blockName := resourceBlock.FullName()
 
 			if resourceBlock.IsResourceType("azurerm_storage_account") {
-				if resourceBlock.MissingChild("network_rules") {
+				if resourceBlock.MissingChild("network_rules") &&
+					len(ctx.GetResourcesByType("azurerm_storage_account_network_rules")) == 0				{
+					set.AddResult().
+						WithDescription("Resource '%s' does not have network_rules and there isn't a configured `azurerm_storage_account_network_rules.", blockName)
 					return
 				}
 				resourceBlock = resourceBlock.GetBlock("network_rules")
