@@ -57,13 +57,15 @@ resource "aws_s3_bucket" "my-bucket" {
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := testutil.CreateBlocksFromSource(test.source, ".tf", t)
-			for _, block := range blocks {
-				if !block.HasChild(test.checkAttribute) {
-					t.FailNow()
+			modules := testutil.CreateModulesFromSource(test.source, ".tf", t)
+			for _, module := range modules {
+				for _, block := range module.GetBlocks() {
+					if !block.HasChild(test.checkAttribute) {
+						t.FailNow()
+					}
+					attr := block.GetAttribute(test.checkAttribute)
+					assert.Equal(t, test.expectedResult, attr.StartsWith(test.checkValue))
 				}
-				attr := block.GetAttribute(test.checkAttribute)
-				assert.Equal(t, test.expectedResult, attr.StartsWith(test.checkValue))
 			}
 		})
 	}
@@ -117,13 +119,15 @@ resource "aws_s3_bucket" "my-bucket" {
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := testutil.CreateBlocksFromSource(test.source, ".tf", t)
-			for _, block := range blocks {
-				if !block.HasChild(test.checkAttribute) {
-					t.FailNow()
+			modules := testutil.CreateModulesFromSource(test.source, ".tf", t)
+			for _, module := range modules {
+				for _, block := range module.GetBlocks() {
+					if !block.HasChild(test.checkAttribute) {
+						t.FailNow()
+					}
+					attr := block.GetAttribute(test.checkAttribute)
+					assert.Equal(t, test.expectedResult, attr.EndsWith(test.checkValue))
 				}
-				attr := block.GetAttribute(test.checkAttribute)
-				assert.Equal(t, test.expectedResult, attr.EndsWith(test.checkValue))
 			}
 		})
 	}
@@ -271,16 +275,18 @@ resource "aws_security_group" "my-security_group" {
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := testutil.CreateBlocksFromSource(test.source, ".tf", t)
-			for _, b := range blocks {
-				if !b.HasChild(test.checkAttribute) {
-					t.FailNow()
-				}
-				attr := b.GetAttribute(test.checkAttribute)
-				if test.ignoreCase {
-					assert.Equal(t, test.expectedResult, attr.Contains(test.checkValue, block.IgnoreCase))
-				} else {
-					assert.Equal(t, test.expectedResult, attr.Contains(test.checkValue))
+			modules := testutil.CreateModulesFromSource(test.source, ".tf", t)
+			for _, module := range modules {
+				for _, b := range module.GetBlocks() {
+					if !b.HasChild(test.checkAttribute) {
+						t.FailNow()
+					}
+					attr := b.GetAttribute(test.checkAttribute)
+					if test.ignoreCase {
+						assert.Equal(t, test.expectedResult, attr.Contains(test.checkValue, block.IgnoreCase))
+					} else {
+						assert.Equal(t, test.expectedResult, attr.Contains(test.checkValue))
+					}
 				}
 			}
 		})
@@ -337,13 +343,15 @@ resource "aws_security_group" "my-security_group" {
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := testutil.CreateBlocksFromSource(test.source, ".tf", t)
-			for _, block := range blocks {
-				if !block.HasChild(test.checkAttribute) {
-					t.FailNow()
+			modules := testutil.CreateModulesFromSource(test.source, ".tf", t)
+			for _, module := range modules {
+				for _, block := range module.GetBlocks() {
+					if !block.HasChild(test.checkAttribute) {
+						t.FailNow()
+					}
+					attr := block.GetAttribute(test.checkAttribute)
+					assert.Equal(t, test.expectedResult, attr.IsAny(test.checkValue...))
 				}
-				attr := block.GetAttribute(test.checkAttribute)
-				assert.Equal(t, test.expectedResult, attr.IsAny(test.checkValue...))
 			}
 		})
 	}
@@ -393,13 +401,15 @@ resource "aws_security_group" "my-security_group" {
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := testutil.CreateBlocksFromSource(test.source, ".tf", t)
-			for _, block := range blocks {
-				if !block.HasChild(test.checkAttribute) {
-					t.FailNow()
+			modules := testutil.CreateModulesFromSource(test.source, ".tf", t)
+			for _, module := range modules {
+				for _, block := range module.GetBlocks() {
+					if !block.HasChild(test.checkAttribute) {
+						t.FailNow()
+					}
+					attr := block.GetAttribute(test.checkAttribute)
+					assert.Equal(t, test.expectedResult, attr.IsNone(test.checkValue...))
 				}
-				attr := block.GetAttribute(test.checkAttribute)
-				assert.Equal(t, test.expectedResult, attr.IsNone(test.checkValue...))
 			}
 		})
 	}
@@ -503,13 +513,15 @@ resource "aws_security_group_rule" "example" {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := testutil.CreateBlocksFromSource(test.source, ".tf", t)
-			for _, block := range blocks {
-				if !block.HasChild(test.checkAttribute) {
-					t.FailNow()
+			modules := testutil.CreateModulesFromSource(test.source, ".tf", t)
+			for _, module := range modules {
+				for _, block := range module.GetBlocks() {
+					if !block.HasChild(test.checkAttribute) {
+						t.FailNow()
+					}
+					attr := block.GetAttribute(test.checkAttribute)
+					assert.Equal(t, test.expectedResult, attr.IsEmpty())
 				}
-				attr := block.GetAttribute(test.checkAttribute)
-				assert.Equal(t, test.expectedResult, attr.IsEmpty())
 			}
 		})
 	}
@@ -546,13 +558,15 @@ resource "numerical_something" "my-bucket" {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := testutil.CreateBlocksFromSource(test.source, ".tf", t)
-			for _, block := range blocks {
-				if !block.HasChild(test.checkAttribute) {
-					t.FailNow()
+			modules := testutil.CreateModulesFromSource(test.source, ".tf", t)
+			for _, module := range modules {
+				for _, block := range module.GetBlocks() {
+					if !block.HasChild(test.checkAttribute) {
+						t.FailNow()
+					}
+					attr := block.GetAttribute(test.checkAttribute)
+					assert.Equal(t, test.expectedResult, attr.LessThan(test.checkValue))
 				}
-				attr := block.GetAttribute(test.checkAttribute)
-				assert.Equal(t, test.expectedResult, attr.LessThan(test.checkValue))
 			}
 		})
 	}
@@ -589,13 +603,15 @@ resource "numerical_something" "my-bucket" {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := testutil.CreateBlocksFromSource(test.source, ".tf", t)
-			for _, block := range blocks {
-				if !block.HasChild(test.checkAttribute) {
-					t.FailNow()
+			modules := testutil.CreateModulesFromSource(test.source, ".tf", t)
+			for _, module := range modules {
+				for _, block := range module.GetBlocks() {
+					if !block.HasChild(test.checkAttribute) {
+						t.FailNow()
+					}
+					attr := block.GetAttribute(test.checkAttribute)
+					assert.Equal(t, test.expectedResult, attr.LessThanOrEqualTo(test.checkValue))
 				}
-				attr := block.GetAttribute(test.checkAttribute)
-				assert.Equal(t, test.expectedResult, attr.LessThanOrEqualTo(test.checkValue))
 			}
 		})
 	}
@@ -638,13 +654,15 @@ resource "boolean_something" "my-something" {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := testutil.CreateBlocksFromSource(test.source, ".tf", t)
-			for _, block := range blocks {
-				if !block.HasChild(test.checkAttribute) {
-					t.FailNow()
+			modules := testutil.CreateModulesFromSource(test.source, ".tf", t)
+			for _, module := range modules {
+				for _, block := range module.GetBlocks() {
+					if !block.HasChild(test.checkAttribute) {
+						t.FailNow()
+					}
+					attr := block.GetAttribute(test.checkAttribute)
+					assert.Equal(t, test.expectedResult, attr.IsTrue())
 				}
-				attr := block.GetAttribute(test.checkAttribute)
-				assert.Equal(t, test.expectedResult, attr.IsTrue())
 			}
 		})
 	}
@@ -687,13 +705,15 @@ resource "boolean_something" "my-something" {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			blocks := testutil.CreateBlocksFromSource(test.source, ".tf", t)
-			for _, block := range blocks {
-				if !block.HasChild(test.checkAttribute) {
-					t.FailNow()
+			modules := testutil.CreateModulesFromSource(test.source, ".tf", t)
+			for _, module := range modules {
+				for _, block := range module.GetBlocks() {
+					if !block.HasChild(test.checkAttribute) {
+						t.FailNow()
+					}
+					attr := block.GetAttribute(test.checkAttribute)
+					assert.Equal(t, test.expectedResult, attr.IsFalse())
 				}
-				attr := block.GetAttribute(test.checkAttribute)
-				assert.Equal(t, test.expectedResult, attr.IsFalse())
 			}
 		})
 	}
